pub struct VfsListResponse {
pub vfses: Vec<String>,
}Expand description
VfsListResponse
JSON schema
{
"type": "object",
"required": [
"vfses"
],
"properties": {
"vfses": {
"description": "VFS name that can be used with other VFS
endpoints.",
"type": "array",
"items": {
"type": "string"
}
}
}
}Fields
vfses: Vec<String>VFS name that can be used with other VFS endpoints.